<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
/**
 * NSC Media module
 * @author: William Adam
 *          
 */
require_once ('application/helpers/safe_helper.php');
safe_module_require_class('fs', 'media_module');
safe_module_require_class('nsc', 'media_profile');
class Nsc_media_module_class extends Fs_media_module_class
{
    /**
     * @brief Create a media profile (overload from base class)
     *
     * @param[in out] $name
     * @param[in out] $data
     *
     * @return 
     */
    public function api_create_profile($name, $data=null) {
        $profile = new Nsc_media_profile_class($this->node() , $this->_obj_base_path .'/profile', $name);
        $profile->configure();
        if($data) {
            $profile->set_data_values($data);
        }
        return $profile;
    }
}
?>
